% -----------------------------code-info----------------------------------%
% This code takes the processed zebrascope data and removes trials with
% EMG activity over 3 standard deviations above mean baseline 
%---- Input ------%
% [.xlsx file] - Output of Zebrascope processing code should be placed in 
%                   the folder with the EMG data collected.
%                   File title: "rootname_SarcomereMeasurments.xlsx"
% [.mat file] - Basline EMG file
% [.mat file] - Trial EMG file 
%
%---- outputs ----%
% [.xlsx file] - SarcomereData_CodeOutput_EMGnoFilt.xlsx
%               this file contains image number and sarcomere values of data 
%               under the 3sd above the baseline
% ------------------------------------------------------------------------%

clear all
close all
clc

prompt{1} = 'Trial Number?';
prompt{2} = 'Basleine trial?';
prompt{3} = 'Number of Raw Zebrascope frames?';
dialoglabel = 'Code Set-Up';
default_ans = {'1','1','100'};
answer = inputdlg(prompt,dialoglabel,1,default_ans);

numtrial = str2double(answer{1});
numbas = str2double(answer{2});

trialString = sprintf('trial%d.mat',numtrial);
trialBas = sprintf('baseline%d.mat',numbas);

%loading Trial and Bas EMG
load(trialString)
trial_t = totalData(:,2);
trial_emg = totalData(:,1);
load(trialBas)
Bas_t = totalData(:,2);
Bas_emg = totalData(:,1);


%% 
%Rectify EMG 
Bas_EMG = abs(Bas_emg);
Trial_EMG = abs(trial_emg);

%ploting EMG
figure (2)
plot(Bas_EMG,'r')
xlabel ('time')
title ('Baseline')
ylabel ('EMG signal')

pause % pause so that you can look at the baseline

%% Prompting what the range is from the displayed graph

prompt2{1} = 'baseline start?';
prompt2{2} = 'baseline end?';
dialoglabel2 = 'Selecting Baseline range';
default_ans2 = {'500','9500'};
answer2 = inputdlg(prompt2,dialoglabel2,1,default_ans2);

offset = mean(Bas_EMG(str2double(answer2{1}):str2double(answer2{2}))); 
offsetsdev = std(Bas_EMG(str2double(answer2{1}):str2double(answer2{2})));

%length of Zebra aquisition
numim = str2double(answer{3}); % this based off of # raw images from Zebrascope 
len = round(numim /1.97)*1000-1000; %1.97HZ is the collection of Zebra, 1kHz is the collection of EMG

%mean of the baseline + 3 * SD of the mean
thres_bas = offset + offsetsdev*3; 

A6 = zeros(1,len);
A6(A6==0) = thres_bas; 

A1 = zeros(1,len);
A1(A1==0) = offset;


%% get emg data into same frame rate as zebrascope
n = round(1000/1.97); % emg collectiong freq over zebra collection freq
a = Trial_EMG (1:len,1); % EMG data from start to end of zebra imaging
b = arrayfun(@(i) mean(a(i:i+n-1)),1:n:length(a)-n+1)'; % averaging every n emg data poitns
time = [n:n:len]';
new_emg(:,1)= time;
new_emg(:,2)= b;

I = find(b < thres_bas);% locate all of the elements in new_emg less than 5% thres
new_emg_under(:,2) = b(I);
new_emg_under(:,1) = time(I);

%% Calculate mean and stdev of sarcomeres measured below EMG threshold
prompt = 'Sarcomere filename?';
filename = input(prompt, 's');
sarc_all = xlsread(filename);

%see if new EMG is also a selected image
new_emg_image = new_emg(:,1)/508;
[Lia1,Locb1] = ismember(sarc_all(:,1),new_emg_image(:,1));

% see if new_emg_under5 is also a selected image
new_emg_under5_image = new_emg_under(:,1)/508;
[Lia,Locb] = ismember(sarc_all(:,1),new_emg_under5_image(:,1));


tt= 1;
for jj = 1:length(Locb)

   allSarc(jj,2) = sarc_all(jj,2); % saving sarcomere value
   allSarc(jj,1) = round(sarc_all(jj,1)/1.97); % saving image time 
    
    if Locb(jj,1) > 0
        finalSarc(tt,2) = sarc_all(jj,2); % saving sarcomere value
        finalSarc(tt,1) = sarc_all(jj,1); % saving image number
        emgvalue(tt,1) = new_emg_under(Locb(jj,1),2); % saving EMG value of selected EMG 
        timevalue(tt,1) = new_emg_under(Locb(jj,1),1);
        tt=tt +1;
    end
    
end


%% plot trial EMG with threshold & slected images with SL
figure
subplot(2,1,1)
hold on
plot(A6,'r')
plot(A1,'r--')
plot(new_emg(:,1),new_emg(:,2),'c')
plot(timevalue(:,1),emgvalue(:,1),'*g')
xlabel('Time (ms)')
ylabel('EMG signal (V)')
hold off

subplot(2,1,2)
plot(allSarc(:,1)*10^3,allSarc(:,2),'ob')
hold on
plot(round(finalSarc(:,1)/1.97)*10^3,finalSarc(:,2),'*g')
ylim([2 6])
ylabel('Sarcomere Length')
xlabel('Time (ms)')
set(gcf,'color','w');
saveas(gcf, 'Selected SL_notfiltered.fig')


%% Saves the output finalSarc in the 10 column of the xls file being read in 
fsarc = table(finalSarc);
writetable(fsarc, 'SarcomereData_CodeOutput_EMGnoFilt.xlsx');
